@@ -36,10 +36,22 @@ else:
     INSTALL_PREFIX = os.path.normpath(INSTALL_PREFIX)
 
 
+def query_hg_for_rev(hgdir, revnum):
+    import subprocess
+    o = subprocess.check_output(('hg', 'log',
+                                 '--repository', os.path.join(hgdir, '..'),
+                                 '-T', '{node|short},{tags}\\n',
+                                 '--rev', revnum))
+    revs = []
+    for line in o.decode(sys.getdefaultencoding()).split('\n'):
+        if line:
+            revs.append(line.split(','))
+    return revs
+
+
 def get_hg_rev():
     hgdir = os.path.join(os.path.dirname(__file__), '..', '.hg')
     if os.path.isdir(hgdir):
-        import subprocess
         last_revision_cache = os.path.join(hgdir, 'cache', 'last_revision')
         if os.path.isfile(last_revision_cache)\
         and (os.path.getmtime(last_revision_cache) >\
@@ -47,28 +59,27 @@ def get_hg_rev():
             with open(last_revision_cache, 'r') as fp:
                 return fp.read()
         else:
+            import subprocess
             try:
-                o = subprocess.check_output(('hg', 'log',
-                        '--repository', os.path.join(hgdir, '..'),
-                        '-T', '{node|short},{tags}',
-                        '--rev', '-2'))
+                lastrevs = query_hg_for_rev(hgdir, '-1:-2')
             except subprocess.CalledProcessError:
                 os.unlink(last_revision_cache)
                 return ''
             else:
-                rev, tag = o.decode(sys.getdefaultencoding()).split(',')
+                tag = lastrevs[1][1] # tagged revision is in second last rev
                 if tag:
                     # This is a tagged revision, thus a release
                     return ''
                 else:
+                    lastrev = lastrevs[0][0]
                     with open(last_revision_cache, 'w') as fp:
-                        fp.write(rev)
-                    return rev
+                        fp.write(lastrev)
+                    return lastrev
     else:
         return ''
 
 
-__version__ = '0.9'
+__version__ = '0.9.1'
 
 hg_rev = get_hg_rev()
 if hg_rev: __version__ += '+hg' + hg_rev
