@@ -408,14 +408,14 @@ class WebalbumDir(make.GroupTask):
             self.break_task = None
 
     def __parse_browse_sizes(self, sizes_defs):
-        for name, string_size in sizes_defs.items():
-            name = py2compat.u(name, locale.getpreferredencoding())
-            if name == '':
-                raise ValueError(_("Sizes is a comma-separated list of size names and specs:\n\t e.g. \"small=640x480,medium=1024x768\"."))
+        for size_defs in sizes_defs:
+            name = py2compat.u(size_defs['name'], locale.getpreferredencoding())
             if name == genmedia.THUMB_SIZE_NAME:
                 raise ValueError(_("Size name '%s' is reserved for internal processing.") % genmedia.THUMB_SIZE_NAME)
-            self.__parse_size(name, string_size)
+            self.__parse_size(name, size_defs['defs'])
             self.browse_sizes.append(name)
+            if 'default' in size_defs and size_defs['default']:
+                self.default_size_name = name
 
     def __parse_size(self, size_name, size_string):
         if size_string == '0x0':
@@ -458,7 +458,6 @@ class WebalbumDir(make.GroupTask):
                           self.config.get('webgal', 'thumbnail-size'))
         self.__parse_size(genmedia.VIDEO_SIZE_NAME,
                           self.config.get('webgal', 'video-size'))
-        self.default_size_name = self.browse_sizes[0]
 
         self.tpl_vars = self.__load_tpl_vars()
         styles = self.album.theme.get_avail_styles(
@@ -708,6 +707,15 @@ class SharedFiles(make.FileMakeObject):
                 self.album.cleanup(file_path, self.path)
 
 
+class DummyProgress(object):
+
+    def dir_done(self):                   pass
+    def media_done(self, how_many=1):     pass
+    def set_task_progress(self, percent): pass
+    def set_task_done(self):              pass
+    def updated(self):                    pass
+
+
 class AlbumGenProgress(object):
 
     def __init__(self, dirs_total, medias_total):
@@ -861,6 +869,9 @@ class Album(object):
             dest_dir = py2compat.u(dest_dir, sys.getfilesystemencoding())
         sane_dest_dir = os.path.abspath(os.path.expanduser(dest_dir))
 
+        if not progress:
+            progress = DummyProgress()
+
         pub_url = self.config.get('global', 'puburl')
         check_all_dirs = self.config.get('runtime', 'check-all-dirs')
 
@@ -928,16 +939,14 @@ class Album(object):
             if check_all_dirs or destgal.needs_build_quick():
                 destgal.make()
             else:
-                if progress is not None:
-                    progress.media_done(self.stats()['bydir'][destgal.source_dir.path])
+                progress.media_done(self.stats()['bydir'][destgal.source_dir.path])
                 logging.info(_("  SKIPPED because of mtime, touch source or use --check-all-dirs to override."))
 
             # Force some memory cleanups, this is usefull for big albums.
             del destgal
             gc.collect()
 
-            if progress is not None:
-                progress.dir_done()
+            progress.dir_done()
 
             logging.info(_("[Leaving  %%ALBUMROOT%%/%s]"), source_dir.strip_root())
 
