@@ -147,7 +147,7 @@ class GstVideoOpener(object):
             if md_success:
                 self.media_duration = media_duration
 
-        if self.progress is not None and self.media_duration is not None\
+        if self.progress and self.media_duration is not None\
         and self.media_duration > 0:
             self.progress.set_task_progress(100 * current_position
                                             // self.media_duration)
@@ -156,7 +156,7 @@ class GstVideoOpener(object):
         stalled = False
         if current_position <= self.last_position:
             self.stalled_counter = self.stalled_counter + 1
-            if self.stalled_counter >= 5:
+            if self.stalled_counter >= 20:
                 stalled = True
                 self.__post_msg('stalled')
         else:
@@ -204,17 +204,11 @@ class GstVideoOpener(object):
                             self.__stop_pipeline()
                             raise VideoError('Pipeline is stalled, this is a problem either in gst or in lazygal\'s use of gst')
 
-        if self.progress is not None:
-            self.progress.set_task_done()
-
     def stop_pipeline(self):
         msg = Gst.Message.new_application(self.pipeline,
             Gst.Structure.new_empty('aborded_playback'))
         self.pipeline.get_bus().post(msg)
 
-        if self.progress is not None:
-            self.progress.set_task_done()
-
 
 class GstVideoInfo(object):
 
@@ -229,7 +223,7 @@ class GstVideoInfo(object):
         discoverer = GstPbutils.Discoverer()
         try:
             info = discoverer.discover_uri(Gst.filename_to_uri(self.path))
-        except GObject.GError as e:
+        except GLib.GError as e:
             raise VideoError(e)
 
         vinfo_caps = info.get_video_streams()[0].get_caps()[0]
@@ -294,19 +288,23 @@ class GstVideoTranscoder(GstVideoReader):
         self.pipeline.add(self.videoenc)
 
         if width is not None and height is not None:
-            self.videoscale = Gst.ElementFactory.make('videoscale',
-                                                      'videoscale')
-            self.videoscale.set_property('method', 'bilinear')
-            self.pipeline.add(self.videoscale)
-            self.colorspace.link(self.videoscale)
+            videoscale = Gst.ElementFactory.make('videoscale', 'videoscale')
+            videoscale.set_property('method', 'bilinear')
+            self.pipeline.add(videoscale)
+            self.colorspace.link(videoscale)
             caps_str = 'video/x-raw,format=YUY2'
             caps_str += ", width=%d, height=%d" % (width, height)
             caps = Gst.Caps.from_string(caps_str)
-            self.caps_filter = Gst.ElementFactory.make('capsfilter', 'filter')
-            self.caps_filter.set_property("caps", caps)
-            self.pipeline.add(self.caps_filter)
-            self.videoscale.link(self.caps_filter)
-            self.caps_filter.link(self.videoenc)
+            caps_filter = Gst.ElementFactory.make('capsfilter', 'filter')
+            caps_filter.set_property("caps", caps)
+            self.pipeline.add(caps_filter)
+            videoscale.link(caps_filter)
+
+            scalequeue = Gst.ElementFactory.make('queue', 'Video scaling queue')
+            self.pipeline.add(scalequeue)
+            caps_filter.link(scalequeue)
+
+            scalequeue.link(self.videoenc)
         else:
             self.colorspace.link(self.videoenc)
 
