@@ -18,8 +18,10 @@
 
 import os
 import time
+import re
 import locale
 import logging
+import fnmatch
 from PIL import Image
 
 from . import py2compat
@@ -91,25 +93,29 @@ class File(make.FileSimpleDependency):
                 raise RuntimeError(_('Root not found'))
         return album_level
 
-    SKIPPED_DIRS = ('.svn', '_darcs', '.bzr', '.git', '.hg', 'CVS', )
-
     def should_be_skipped(self):
         head = self.strip_root()
         while head != '':
             head, tail = os.path.split(head)
-            if tail in File.SKIPPED_DIRS:
-                return True
+            for pattern in self.album.excludes:
+                if fnmatch.fnmatch(tail, pattern):
+                    return True
         return False
 
     def get_datetime(self):
         return py2compat.datetime.fromtimestamp(self.get_mtime())
 
+    def name_numeric(self):
+        numeric_part = re.sub("\D", "", self.filename)
+        return numeric_part and int(numeric_part) or 0
+
 
 class MediaFile(File):
 
     def __init__(self, path, album):
         File.__init__(self, path, album)
         self.broken = False
+        self._size = None
 
         comment_file_path = self.path + metadata.FILE_METADATA_MEDIA_SUFFIX
         if os.path.isfile(comment_file_path):
@@ -149,8 +155,12 @@ class ImageFile(MediaFile):
         return exif
 
     def get_size(self, img_path=None):
+        myself = False
         if not img_path:
             img_path = self.path
+            if self._size is not None:
+                return self._size
+            myself = True
 
         with open(img_path, 'rb') as im_fp:
             try:
@@ -159,6 +169,8 @@ class ImageFile(MediaFile):
                 self.broken = True
                 return (None, None)
             else:
+                if myself:
+                    self._size = im.size
                 return im.size
 
     def has_reliable_date(self):
@@ -186,13 +198,15 @@ class VideoFile(MediaFile):
     type = 'video'
 
     def get_size(self):
-        inspector = mediautils.GstVideoInfo(self.path)
-        try:
-            inspector.inspect()
-        except mediautils.VideoError:
-            self.broken = True
-            return (None, None)
-        return inspector.videowidth, inspector.videoheight
+        if self._size is None:
+            inspector = mediautils.GstVideoInfo(self.path)
+            try:
+                inspector.inspect()
+            except mediautils.VideoError:
+                self.broken = True
+                return (None, None)
+            self._size = inspector.videowidth, inspector.videoheight
+        return self._size
 
     def has_reliable_date(self):
         return False
@@ -220,17 +234,33 @@ class MediaHandler(object):
         self.album = album
 
     @staticmethod
-    def is_known_media(path):
+    def is_known_media(path, album):
+        tail = os.path.basename(path)
+        for pattern in album.excludes:
+            if fnmatch.fnmatch(tail, pattern):
+                return False
         filename, extension = os.path.splitext(path)
         extension = extension.lower()
         return extension in MediaHandler.FORMATS.keys()
 
+    NO_VIDEO_SUPPORT_WARNING_ISSUED = False
+
+    @staticmethod
+    def warn_no_video_support():
+        if not MediaHandler.NO_VIDEO_SUPPORT_WARNING_ISSUED:
+            logging.warning(_('Video support is disabled: could not load GStreamer'))
+
     def get_media(self, path):
+        tail = os.path.basename(path)
+        for pattern in self.album.excludes:
+            if fnmatch.fnmatch(tail, pattern):
+                return None
         filename, extension = os.path.splitext(path)
         extension = extension.lower()
         if extension in MediaHandler.FORMATS.keys():
             media_class = MediaHandler.FORMATS[extension]
             if media_class == VideoFile and not mediautils.HAVE_GST:
+                MediaHandler.warn_no_video_support()
                 return None
             return media_class(path, self.album)
         else:
@@ -285,7 +315,7 @@ class Directory(File):
             self.desc = None
 
         if 'album_picture' in md.keys():
-            self.album_picture = self.rel_path(self, md['album_picture'])
+            self.album_picture = md['album_picture']
         else:
             self.album_picture = None
 
@@ -367,14 +397,14 @@ class Directory(File):
         media_stamp_max = None
         for m in all_medias:
             if m.has_reliable_date():
-                media_stamp = m.get_date_taken().timestamp
+                media_stamp = m.get_date_taken().timestamp()
                 if media_stamp_max is None or media_stamp > media_stamp_max:
                     media_stamp_max = media_stamp
 
         if media_stamp_max is None:
             # none of the media had a reliable date, use mtime instead
             for m in all_medias:
-                media_stamp = time.mktime(m.get_mtime().timetuple())
+                media_stamp = m.get_datetime().timestamp()
                 if media_stamp_max is None or media_stamp > media_stamp_max:
                     media_stamp_max = media_stamp
 
