@@ -23,6 +23,22 @@ import posixpath
 from . import pathutils
 
 
+FILESIZE_UNIT_PREFIXES = (
+    ('T', 2 ** 40),
+    ('G', 2 ** 30),
+    ('M', 2 ** 20),
+    ('K', 2 ** 10),
+)
+
+
+def format_filesize(size_bytes):
+    for unit_prefix, limit in FILESIZE_UNIT_PREFIXES:
+        if size_bytes >= limit:
+            return '%.1f %siB'\
+                    % (round(float(size_bytes) / limit, 1), unit_prefix)
+    return '%.1f B' % size_bytes
+
+
 class TemplateVariables(object):
 
     def __init__(self, page):
@@ -73,7 +89,7 @@ class Image(Media):
 
         tpl_values['img_width'], tpl_values['img_height'] = self.webalbum_media.resized[self.page.size_name].get_size()
 
-        if self.page.dir.config.getboolean('webgal', 'publish-metadata'):
+        if self.page.dir.config.get('webgal', 'publish-metadata'):
             tpl_values['publish_metadata'] = True
             img_date = self.media.get_date_taken()
             tpl_values['image_date'] = img_date.strftime(_("on %d/%m/%Y at %H:%M"))
@@ -104,7 +120,7 @@ class Video(Media):
 
     def full(self):
         tpl_values = self.link()
-        tpl_values['video_src'] = self.webalbum_media.resized[self.page.size_name].filename
+        tpl_values['video_src'] = self.webalbum_media.resized[self.page.size_name].rel_path(self.page.dir, url=True)
         tpl_values['video_src'] = pathutils.url_quote(tpl_values['video_src'])
         return tpl_values
 
@@ -179,22 +195,26 @@ class Webgal(SrcPath):
         dir_info = {}
         if self.webgal.source_dir.metadata:
             dir_info.update(self.webgal.source_dir.metadata.get())
-            if 'album_description' in dir_info.keys():
-                dir_info['album_description'] =\
-                    self.page._do_not_escape(dir_info['album_description'])
+
+        for html_key in ('album_name', 'album_description'):
+            if html_key in dir_info:
+                dir_info[html_key] =\
+                    self.page._do_not_escape(dir_info[html_key])
 
         if 'album_name' not in dir_info:
             dir_info['album_name'] = self.webgal.source_dir.human_name
 
-        if self.webgal.dirzip:
-            archive_rel_path = self.webgal.dirzip.rel_path(self.page.dir,
-                                                           url=True)
+        dirzip = self.webgal.pindex.dirzip()
+        if dirzip:
+            archive_rel_dir = self.webgal.rel_path(self.page.dir.path)
+            archive_rel_path = posixpath.join(archive_rel_dir,
+                                              dirzip['filename'])
             dir_info['dirzip'] = pathutils.url_quote(archive_rel_path)
-            dir_info['dirzip_size'] = self.page.format_filesize(self.webgal.dirzip.size())
+            dir_info['dirzip_size'] = dirzip['sizestr']
 
         dir_info['is_main'] = self.webgal is self.page.dir
 
-        dir_info['image_count'] = self.webgal.get_media_count('image')
+        dir_info['image_count'] = self.webgal.pindex.get_media_count('image')
         dir_info['subgal_count'] = len(self.webgal.source_dir.subdirs)
 
         dir_info['id'] = pathutils.url_quote(self.id())
