@@ -21,6 +21,7 @@ import unittest
 import os
 import locale
 import datetime
+import codecs
 
 
 from . import LazygalTest
@@ -84,8 +85,49 @@ class TestFileMetadata(LazygalTest):
         self.album_root = Directory(self.source_dir, [], [],
                                     self.album_root.album)
 
-        self.assertEqual(os.path.join(self.source_dir, img_names[0]),
-                         self.album_root.album_picture)
+        self.assertEqual(img_names[0], self.album_root.album_picture)
+
+    def test_matew_metadata_album_picture(self):
+        img_names = ('ontop.jpg', 'second.jpg', 'realtitle.jpg')
+        for img_name in img_names:
+            self.add_img(self.source_dir, img_name)
+
+        self.create_file(os.path.join(self.source_dir, 'album_description'),'''
+Album image identifier "realtitle.jpg"
+''')
+
+        # Reload the directory now that the metadata file is created
+        self.album_root = Directory(self.source_dir, [], [],
+                                    self.album_root.album)
+
+        self.assertEqual(img_names[2], self.album_root.album_picture)
+
+    def test_auto_metadata_album_picture(self):
+        img_names = ('ontop.jpg', 'second.jpg', )
+        for img_name in img_names:
+            self.add_img(self.source_dir, img_name)
+
+        self.album_root = Directory(self.source_dir, [], img_names,
+                                    self.album_root.album)
+
+        self.assertEqual(img_names[0], self.album_root.album_picture)
+
+    def test_gen_metadata(self):
+        img_names = (u'first\xe3.jpg', 'second.jpg', )
+        for img_name in img_names:
+            self.add_img(self.source_dir, img_name)
+
+        self.album_root.album.generate_default_metadata()
+
+        with codecs.open(os.path.join(self.source_dir, 'album_description'),
+                         'r', 'utf-8') as f:
+            fmd = f.read()
+
+        self.assertEqual(fmd, u'''# Directory metadata for lazygal, Matew format
+Album name "%s"
+Album description ""
+Album image identifier "first\xe3.jpg"
+''' % os.path.basename(self.source_dir))
 
     def test_comment_none(self):
         im_md = metadata.ImageInfoTags(self.get_sample_path('sample.jpg'))
@@ -183,6 +225,10 @@ class TestFileMetadata(LazygalTest):
         im_md = metadata.ImageInfoTags(self.get_sample_path(sample))
         self.assertEqual(im_md.get_focal_length(), '18 mm (35 mm equivalent: 27 mm)')
 
+    @unittest.skipIf(py2compat.PY3RUNNING
+                     and (GExiv2.MAJOR_VERSION, GExiv2.MINOR_VERSION,
+                          GExiv2.MICRO_VERSION) < (0, 10, 3),
+                     'not supported by GExiv2<0.10.3 in python3')
     def test_authorship(self):
         sample = 'sample-author-badencoding.jpg'
         im_md = metadata.ImageInfoTags(self.get_sample_path(sample))
